@@ -1,3 +1,4 @@
+import datetime
 import python_framework.api.src.service.SqlAlchemyProxy as sap
 from python_framework.api.src.model.FrameworkModel import ERROR_LOG, MODEL
 
@@ -11,8 +12,6 @@ MAX_RESOURCE_METHOD_NAME_SIZE = 128
 class ErrorLog(MODEL):
     __tablename__ = ERROR_LOG
 
-    id = sap.Column(sap.Integer(), sap.Sequence(f'{__tablename__}{sap.ID}{sap.SEQ}'), primary_key=True)
-    timeStamp = sap.Column(sap.DateTime())
     status = sap.Column(sap.Integer())
     verb = sap.Column(sap.String(MAX_VERB_SIZE))
     url = sap.Column(sap.String(MAX_URL_SIZE))
@@ -21,10 +20,10 @@ class ErrorLog(MODEL):
     logPayload = sap.Column(sap.String(MAX_HTTP_ERROR_LOG_PAYLOAD_SIZE))
     logResource = sap.Column(sap.String(MAX_RESOURCE_NAME_SIZE))
     logResourceMethod = sap.Column(sap.String(MAX_RESOURCE_METHOD_NAME_SIZE))
+    timeStamp = sap.Column(sap.DateTime(), default=datetime.datetime.utcnow)
+    id = sap.Column(sap.Integer(), sap.Sequence(f'{__tablename__}{sap.ID}{sap.SEQ}'), primary_key=True)
 
     def __init__(self,
-        id = None,
-        timeStamp = None,
         status = None,
         verb = None,
         url = None,
@@ -32,9 +31,10 @@ class ErrorLog(MODEL):
         logMessage = None,
         logPayload = None,
         logResource = None,
-        logResourceMethod = None
+        logResourceMethod = None,
+        timeStamp = None,
+        id = None
     ):
-        self.timeStamp = timeStamp
         self.status = status
         self.verb = str(verb)[:MAX_VERB_SIZE-1]
         self.url = str(url)[:MAX_URL_SIZE-1]
@@ -43,10 +43,10 @@ class ErrorLog(MODEL):
         self.logPayload = str(logPayload)[:MAX_HTTP_ERROR_LOG_PAYLOAD_SIZE-1]
         self.logResource = str(logResource)[:MAX_RESOURCE_NAME_SIZE-1]
         self.logResourceMethod = str(logResourceMethod)[:MAX_RESOURCE_METHOD_NAME_SIZE-1]
+        self.timeStamp = timeStamp
         self.id = id
 
     def override(self, globalException):
-        self.timeStamp = globalException.timeStamp
         self.status = globalException.status
         self.verb = str(globalException.verb)[:MAX_VERB_SIZE-1]
         self.url = str(globalException.url)[:MAX_URL_SIZE-1]
@@ -55,6 +55,7 @@ class ErrorLog(MODEL):
         self.logPayload = str(globalException.logPayload)[:MAX_HTTP_ERROR_LOG_PAYLOAD_SIZE-1]
         self.logResource = str(globalException.logResource)[:MAX_RESOURCE_NAME_SIZE-1]
         self.logResourceMethod = str(globalException.logResourceMethod)[:MAX_RESOURCE_METHOD_NAME_SIZE-1]
+        self.timeStamp = globalException.timeStamp
 
     def __repr__(self):
         return f'{self.__tablename__}(verb={self.verb}, url={self.url}, status={self.status}, message={self.message}, id={self.id})'
